Package: BioVizSeq
Type: Package
Title: Visualizing the Elements Within Bio-Sequences
Version: 1.0.5
Authors@R: 
    person("Shiqi", "Zhao", , "zhaosq89@163.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-2360-956X"))
Maintainer: Shiqi Zhao <zhaosq89@163.com>
Description: Visualizing the types and distribution of elements within
  bio-sequences. At the same time, We have developed a geom layer,
  geom_rrect(), that can generate rounded rectangles. No external references
  are used in the development of this package.
Encoding: UTF-8
License: Artistic-2.0
Language: en-US
RoxygenNote: 7.2.3
Repository: CRAN
Imports: dplyr, ggplot2, httr, RColorBrewer, seqinr, stringr, tidyr,
        magrittr, ggtree, treeio, ggh4x, shiny
NeedsCompilation: no
Packaged: 2026-01-10 11:22:55 UTC; zhaoshiqi
Author: Shiqi Zhao [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-2360-956X>)
Date/Publication: 2026-01-10 12:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 16:41:42 UTC; unix
