# Generated by roxygen2: do not edit by hand

export(ProtParam_calc)
export(biovizseq)
export(cdd_plot)
export(cdd_to_loc)
export(combi_p)
export(combi_p2)
export(fastaleng)
export(geom_rrect)
export(gff_plot)
export(gff_statistics)
export(gff_to_loc)
export(meme_plot)
export(meme_seq)
export(meme_to_loc)
export(motif_plot)
export(pfam_plot)
export(pfam_to_loc)
export(plantcare_classify)
export(plantcare_plot)
export(plantcare_plot1)
export(plantcare_plot2)
export(plantcare_plot3)
export(plantcare_statistic1)
export(plantcare_statistic2)
export(plantcare_to_loc)
export(smart_plot)
export(smart_to_loc)
export(upload_fa_to_plantcare)
import(ggh4x)
import(ggplot2)
import(ggtree)
import(httr)
importFrom(RColorBrewer,brewer.pal)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,n)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(ggplot2,Geom)
importFrom(ggplot2,aes)
importFrom(ggplot2,draw_key_polygon)
importFrom(ggplot2,ggproto)
importFrom(grid,roundrectGrob)
importFrom(magrittr,"%>%")
importFrom(seqinr,read.fasta)
importFrom(seqinr,write.fasta)
importFrom(shiny,runApp)
importFrom(stats,aggregate)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stringr,str_detect)
importFrom(tidyr,complete)
importFrom(tidyr,separate)
importFrom(treeio,read.newick)
importFrom(utils,read.table)
importFrom(utils,write.table)
